package
Version:
v0.0.0-...-dde1ccd
Opens a new window with list of versions in this module.
Published: May 22, 2024
License: CC0-1.0
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Gato struct {
ID bson.ObjectId `bson:"_id" json:"id"`
Name string `bson:"name" json:"name"`
Image string `bson:"image" json:"image"`
Description string `bson:"description" json:"description"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.